@@ -5,11 +5,12 @@ import sys
 
 from datalake_scripts.common.base_script import BaseScripts
 from datalake_scripts.scripts import add_threats, get_threats_by_hashkey, edit_score, get_threats_from_query_hash, \
-    add_comments, lookup_threats, add_tags, get_query_hash
+    add_comments, lookup_threats, add_tags, get_query_hash, bulk_lookup_threats
 
 
 class Cli:
     CLI_NAME = BaseScripts.PACKAGE_NAME
+    VERSION = '2.3.1'
 
     def __init__(self):
         parser = argparse.ArgumentParser(
@@ -25,10 +26,17 @@ The most commonly used {self.CLI_NAME} commands are:
             epilog='Don\'t hesitate to leave a feedback on https://datalake.cert.orangecyberdefense.com/gui/ using the '
                    '"Add Feedback" button '
         )
-        parser.add_argument('command', help='Subcommand to run', choices=self._list_commands_available())
+
+        parser.add_argument('--version', '-V', default=False, action='store_true', help='prints the current version')
+        parser.add_argument('command', nargs='?', help='Subcommand to run', choices=self._list_commands_available())
         # parse_args defaults to [1:] for args, but you need to
         # exclude the rest of the args too, or validation will fail
         args = parser.parse_args(sys.argv[1:2])
+
+        if args.version:
+            print(self.VERSION)
+            exit(0)
+
         if not hasattr(self, args.command):
             print('Unrecognized command')
             parser.print_help()
@@ -68,6 +76,10 @@ The most commonly used {self.CLI_NAME} commands are:
         args = sys.argv[2:]
         lookup_threats.main(args)
 
+    def bulk_lookup_threats(self):
+        args = sys.argv[2:]
+        bulk_lookup_threats.main(args)
+
     def _list_commands_available(self):
         method_list = []
         for method_name in dir(self):
