@@ -4,19 +4,26 @@ Extend this engine to give it more functionality.
 """
 import os
 import json
+import parser
+import requests
+
 from json.decoder import JSONDecodeError
 from typing import Union
 from urllib.parse import urljoin
 
-import requests
 from requests import Response
 
+from datalake_scripts.common import suppress_insecure_request_warns
 from datalake_scripts.common.logger import logger
 from datalake_scripts.common.throttler import throttle
 from datalake_scripts.common.token_manager import TokenGenerator
 
 
 class BaseEngine:
+    ACCEPTED_HEADERS = {
+        'json': 'application/json',
+        'csv': 'text/csv'
+    }
     OCD_DTL_QUOTA_TIME = int(os.getenv('OCD_DTL_QUOTA_TIME', 1))
     OCD_DTL_REQUESTS_PER_QUOTA_TIME = int(os.getenv('OCD_DTL_REQUESTS_PER_QUOTA_TIME', 5))
     logger.debug(f'Throttle selected: {OCD_DTL_REQUESTS_PER_QUOTA_TIME} queries per {OCD_DTL_QUOTA_TIME}s')
@@ -28,12 +35,12 @@ class BaseEngine:
     def __init__(self, endpoint_config: dict, environment: str, tokens: list):
         self.endpoint_config = endpoint_config
         self.environment = environment
+        self.requests_ssl_verify = suppress_insecure_request_warns(environment)
         self.url = self._build_url(endpoint_config, environment)
         self.tokens = tokens
         self.terminal_size = self._get_size_terminal()
         self.token_generator = TokenGenerator(endpoint_config, environment=environment)
         self.headers = None
-
         self.SET_MAX_RETRY = 3
 
     def _get_size_terminal(self) -> int:
@@ -75,6 +82,8 @@ class BaseEngine:
             elif response.status_code < 200 or response.status_code > 299:
                 logger.error(f'API returned non 2xx response code : {response.status_code}\n{response.text}'
                              f'\n Retrying')
+            elif 'Content-Type' in response.headers and 'text/csv' in response.headers['Content-Type']:
+                return response.text
             else:
                 try:
                     dict_response = self._load_response(response)
@@ -87,6 +96,18 @@ class BaseEngine:
                 return {}
             # time.sleep(5)
 
+    @staticmethod
+    def output_type2header(value):
+        """
+        this method gets the CLI input arg value and generate the header content-type
+        :param value: value to header
+        :return: returns content-type header or raise an exception if there isn't an associated content-type value
+        """
+        if value.lower() in BaseEngine.ACCEPTED_HEADERS:
+            return BaseEngine.ACCEPTED_HEADERS[value.lower()]
+
+        raise parser.ParserError(f'{value.lower()} is not a valid. Use some of {BaseEngine.ACCEPTED_HEADERS.keys()}')
+
     def _send_request(self, url: str, method: str, headers: dict, data: dict):
         """
         Send the correct http request to url from method [get, post, delete, patch, put].
@@ -99,16 +120,22 @@ class BaseEngine:
         :param tokens: list
         :return: str
         """
+        common_kwargs = {
+            'url': url,
+            'headers': headers,
+            'verify': self.requests_ssl_verify
+        }
+
         if method == 'get':
-            api_response = requests.get(url=url, headers=headers)
+            api_response = requests.get(**common_kwargs)
         elif method == 'post':
-            api_response = requests.post(url=url, headers=headers, data=json.dumps(data))
+            api_response = requests.post(**common_kwargs, data=json.dumps(data))
         elif method == 'delete':
-            api_response = requests.delete(url=url, headers=headers, data=json.dumps(data))
+            api_response = requests.delete(**common_kwargs, data=json.dumps(data))
         elif method == 'patch':
-            api_response = requests.patch(url=url, headers=headers, data=json.dumps(data))
+            api_response = requests.patch(**common_kwargs, data=json.dumps(data))
         elif method == 'put':
-            api_response = requests.put(url=url, headers=headers, data=json.dumps(data))
+            api_response = requests.put(**common_kwargs, data=json.dumps(data))
         else:
             logger.debug('ERROR : Wrong requests, please only do [get, post, put, patch, delete] method')
             raise TypeError('Unknown method to requests %s', method)
